==> haskell-wizards-1.0.3-17-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wizards
version:              1.0.3
visibility:           public
id:                   wizards-1.0.3-KdOLRFMRRl1t6euiwGd
key:                  wizards-1.0.3-KdOLRFMRRl1t6euiwGd
license:              BSD-3-Clause
maintainer:           liamoc@cse.unsw.edu.au
author:               Liam O'\''Connor-Davis
synopsis:
    High level, generic library for interrogative user interfaces

description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.

    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.

    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.


    See the github page for examples on usage:

    <http://www.github.com/liamoc/wizards>

    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.

category:             User Interfaces
abi:                  f1755e56e8ac9f08140218c2cd29c1b8
exposed:              True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wizards-1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wizards-1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wizards-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wizards
hs-libraries:         HSwizards-1.0.3-KdOLRFMRRl1t6euiwGd
depends:
    base-4.17.2.1 containers-0.6.7
    control-monad-free-0.6.2-Bsk294wsAdBAFVbMh4Lqn8 haskeline-0.8.2
    mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html:         /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wizards-1.0.3-18-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wizards
version:              1.0.3
visibility:           public
id:                   wizards-1.0.3-kQD0EpqpVQ3BeMLTHRbtJ
key:                  wizards-1.0.3-kQD0EpqpVQ3BeMLTHRbtJ
license:              BSD-3-Clause
maintainer:           liamoc@cse.unsw.edu.au
author:               Liam O'\''Connor-Davis
synopsis:
    High level, generic library for interrogative user interfaces

description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.

    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.

    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.


    See the github page for examples on usage:

    <http://www.github.com/liamoc/wizards>

    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.

category:             User Interfaces
abi:                  6c29d73130c5aa294faba91a320f8ed2
exposed:              True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/wizards-1.0.3
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/wizards-1.0.3
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/wizards-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wizards
hs-libraries:         HSwizards-1.0.3-kQD0EpqpVQ3BeMLTHRbtJ
depends:
    base-4.18.3.0 containers-0.6.7
    control-monad-free-0.6.2-DvQCvdIeSho8FPY8qDEAWS haskeline-0.8.2.1
    mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html:         /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
